@@ -16,19 +16,20 @@ from .context import Context, ScopedContext
 from .config_client import ConfigClient
 from .feature_flag_client import FeatureFlagClient
 from .options import Options
-from ._requests import TimeoutHTTPAdapter
+from ._requests import TimeoutHTTPAdapter, VersionHeader, Version
 from typing import Optional, Union
 import prefab_pb2 as Prefab
 import uuid
 import requests
 from urllib.parse import urljoin
-from importlib.metadata import version
-from .constants import NoDefaultProvided, ConfigValueType, ContextDictType
+from .constants import (
+    NoDefaultProvided,
+    ConfigValueType,
+    ContextDictOrContext,
+)
 from ._internal_constants import LOG_LEVEL_BASE_KEY
 
 PostBodyType = Union[Prefab.Loggers, Prefab.ContextShapes, Prefab.TelemetryEvents]
-Version = version("prefab-cloud-python")
-VersionHeader = "X-PrefabCloud-Client-Version"
 logger = InternalLogger(__name__)
 LLV = Prefab.LogLevel.Value
 
@@ -40,16 +41,17 @@ class Client:
     def __init__(self, options: Options) -> None:
         self.shutdown_flag = threading.Event()
         self.options = options
+        self.global_context = options.global_context
         self.instance_hash = str(uuid.uuid4())
         self.telemetry_manager = TelemetryManager(self, options)
         if not options.is_local_only():
             self.telemetry_manager.start_periodic_sync()
-        self.api_url = options.prefab_api_url
+        self.api_urls = options.prefab_api_urls
         # Define the retry strategy
         retry_strategy = Retry(
             total=2,  # Maximum number of retries
             status_forcelist=[429, 500, 502, 503, 504],  # HTTP status codes to retry on
-            allowed_methods=["POST"],
+            allowed_methods=["POST", "GET"],
         )
         # Create an TimeoutHTTPAdapter adapter with the retry strategy and a standard timeout and mount it to session
         adapter = TimeoutHTTPAdapter(max_retries=retry_strategy, timeout=5)
@@ -62,7 +64,7 @@ class Client:
             logger.info(
                 f"Prefab {Version} connecting to %s, secure %s"
                 % (
-                    options.prefab_api_url,
+                    options.prefab_api_urls,
                     options.http_secure,
                 ),
             )
@@ -80,7 +82,7 @@ class Client:
         self,
         key: str,
         default: ConfigValueType = NoDefaultProvided,
-        context: Optional[ContextDictType | Context] = None,
+        context: Optional[ContextDictOrContext] = None,
     ) -> ConfigValueType:
         if self.is_ff(key):
             return self.feature_flag_client().get(key, default=default, context=context)
@@ -88,7 +90,7 @@ class Client:
             return self.config_client().get(key, default=default, context=context)
 
     def enabled(
-        self, feature_name: str, context: Optional[ContextDictType | Context] = None
+        self, feature_name: str, context: Optional[ContextDictOrContext] = None
     ) -> bool:
         return self.feature_flag_client().feature_is_on_for(
             feature_name, context=context
@@ -147,7 +149,7 @@ class Client:
             "Accept": "application/x-protobuf",
         }
 
-        endpoint = urljoin(self.options.prefab_api_url or "", path)
+        endpoint = urljoin(self.options.telemetry_url or "", path)
 
         return self.session.post(
             endpoint,
@@ -164,6 +166,12 @@ class Client:
     def is_ready(self) -> bool:
         return self.config_client().is_ready()
 
+    def set_global_context(
+        self, global_context: Optional[ContextDictOrContext] = None
+    ) -> Client:
+        self.global_context = Context.normalize_context_arg(global_context)
+        return self
+
     def close(self) -> None:
         if not self.shutdown_flag.is_set():
             logger.info("Shutting down prefab client instance")
