@@ -7,8 +7,9 @@ class ConfigValueWrapper:
     @staticmethod
     def wrap(value, confidential=None):
         value_type = type(value)
-
-        if value_type == int:
+        if value_type == Prefab.ConfigValue:
+            return value
+        elif value_type == int:
             return Prefab.ConfigValue(int=value, confidential=confidential)
         elif value_type == float:
             return Prefab.ConfigValue(double=value, confidential=confidential)
